@@ -46,7 +46,7 @@ sub get_column {
         Carp::croak('please specify $col for first argument');
     }
 
-    my $data = exists $self->{row_data}->{$col} ? $self->{row_data}->{$col} : Carp::croak("$col no selected column.");
+    my $data = exists $self->{row_data}->{$col} ? $self->{row_data}->{$col} : Carp::croak("$col no selected column. SQL: " . ($self->{sql}||'unknown'));
 
     return $self->{skinny}->schema->utf8_on($col, $data);
 }
